@@ -17,7 +17,6 @@ class LexSubExample:
                  word_pos: int,
                  key: str = None,
                  idx: str = None):
-
         self.key = key
         self.id = idx
         self.context = context
@@ -48,6 +47,6 @@ class Candidate:
     # Define your scoring function below
     @property
     def ranking_score(self):
-        return self.wt_lm_score * self.lm_score \
-               + self.wt_word_sim_score * self.static_word_sim
-
+        combined_score = (self.wt_lm_score * self.lm_score + self.wt_word_sim_score * self.static_word_sim)
+        weight = (self.wt_lm_score + self.wt_word_sim_score)
+        return float(combined_score) / float(weight)
